#!/bin/perl

#
#	tdsexample.p
#	===============================================================================
#		Blame        : Kevin Lyons <kevin@nol.org>
#		Created      : 2005-02-09 
#		Last Updated : 2005-02-09
#		Copyright(c) 2005 Kevin Lyons
#	===============================================================================
#	Description
#	-----------
#		Example code for connecting and querying through the DBI::Sybase module
#	built on the FreeTDS library code.
#	===============================================================================
#

use DBI;
use strict;

# -- EDIT HERE -> add your server, username and password 
my $SERVER = "foo";
my $USER   = "user";
my $PASS   = "pass";

#	-- Establish our connection to the server. Note that we're just using the 
#	   run of the mill connection string, look at the perldocs for DBI for 
#	   more options. It's not uncommon here especially to set the packetsize=512
#	   option
my $dbh = DBI->connect("dbi:Sybase:server=$SERVER", $USER, $PASS);
if (!$dbh) {
	print STDERR "Unable to connect to $SERVER: $DBI::errstr\n";
	exit 1;
}

# -- EDIT HERE -> add your own query
my $query = "select Column1, Column2 from MyTable";

#	-- Get our query ready to do, make sure it's valid, etc.
my $stmt = $dbh->prepare($query);
if (!$stmt) {
	print STDERR "Can't prepare query '$query': $DBI::errstr\n";
	$dbh->disconnect;
	exit 1;
}

# -- And run the sucker
if (!$stmt->execute) {
	print STDERR "Can't execute query '$query': $DBI::errstr\n";
	$dbh->disconnect;
	exit 1;
}

# -- now process the results as Column " " Column " " , etc.
my @row;
while (@row = $stmt->fetchrow) {
	foreach my $val (@row) { print $val . " "; }
	print "\n";
}

# -- and exit nicely!
$dbh->disconnect;

exit 0;
